==> avro-doc-1.11.0.tar.gz: avro-doc-1.11.0/api/cpp/html/search/all_2.js <==
var searchData=
[
  ['close_32',['close',['../classavro_1_1DataFileWriterBase.html#abc2bf032070c962eee3628abbb062edf',1,'avro::DataFileWriterBase::close()'],['../classavro_1_1DataFileWriter.html#a3ed294a4c9e3641b4cbd383ede5aedc1',1,'avro::DataFileWriter::close()'],['../classavro_1_1DataFileReaderBase.html#ad10eaf9462e2464c37d3a1f4eebc702b',1,'avro::DataFileReaderBase::close()'],['../classavro_1_1DataFileReader.html#af92068c4498f900939e3208a2c370b2e',1,'avro::DataFileReader::close()']]],
  ['codec_33',['Codec',['../namespaceavro.html#a348c1fae0c6b9d7524b00be30a2746b2',1,'avro']]],
  ['codec_5ftraits_34',['codec_traits',['../structavro_1_1codec__traits.html',1,'avro']]],
  ['codec_5ftraits_3c_20avro_3a_3anull_20_3e_35',['codec_traits&lt; avro::null &gt;',['../structavro_1_1codec__traits_3_01avro_1_1null_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20bool_20_3e_36',['codec_traits&lt; bool &gt;',['../structavro_1_1codec__traits_3_01bool_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20double_20_3e_37',['codec_traits&lt; double &gt;',['../structavro_1_1codec__traits_3_01double_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20float_20_3e_38',['codec_traits&lt; float &gt;',['../structavro_1_1codec__traits_3_01float_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20genericdatum_20_3e_39',['codec_traits&lt; GenericDatum &gt;',['../structavro_1_1codec__traits_3_01GenericDatum_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20int32_5ft_20_3e_40',['codec_traits&lt; int32_t &gt;',['../structavro_1_1codec__traits_3_01int32__t_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20int64_5ft_20_3e_41',['codec_traits&lt; int64_t &gt;',['../structavro_1_1codec__traits_3_01int64__t_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3aarray_3c_20uint8_5ft_2c_20n_20_3e_20_3e_42',['codec_traits&lt; std::array&lt; uint8_t, N &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1array_3_01uint8__t_00_01N_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3aconditional_3c_20avro_3a_3ais_5fnot_5fdefined_3c_20bool_5fcodec_5ftraits_20_3e_3a_3avalue_2c_20std_3a_3avector_3c_20bool_20_3e_3a_3aconst_5freference_2c_20void_20_3e_3a_3atype_20_3e_43',['codec_traits&lt; std::conditional&lt; avro::is_not_defined&lt; bool_codec_traits &gt;::value, std::vector&lt; bool &gt;::const_reference, void &gt;::type &gt;',['../structavro_1_1codec__traits_3_01std_1_1conditional_3_01avro_1_1is__not__defined_3_01bool__codec_ff37ba08cb2504ad1efb9929401153b7.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3amap_3c_20std_3a_3astring_2c_20t_20_3e_20_3e_44',['codec_traits&lt; std::map&lt; std::string, T &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1map_3_01std_1_1string_00_01T_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3apair_3c_20validschema_2c_20genericdatum_20_3e_20_3e_45',['codec_traits&lt; std::pair&lt; ValidSchema, GenericDatum &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1pair_3_01ValidSchema_00_01GenericDatum_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3astring_20_3e_46',['codec_traits&lt; std::string &gt;',['../structavro_1_1codec__traits_3_01std_1_1string_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3avector_3c_20t_20_3e_20_3e_47',['codec_traits&lt; std::vector&lt; T &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1vector_3_01T_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3avector_3c_20uint8_5ft_20_3e_20_3e_48',['codec_traits&lt; std::vector&lt; uint8_t &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1vector_3_01uint8__t_01_4_01_4.html',1,'avro']]],
  ['compilejsonschema_49',['compileJsonSchema',['../namespaceavro.html#a31c14823127aff747cc83e6714de9e31',1,'avro::compileJsonSchema(std::istream &amp;is, ValidSchema &amp;schema)'],['../namespaceavro.html#a23cb7c42622aad8310cffa013c022d14',1,'avro::compileJsonSchema(std::istream &amp;is, ValidSchema &amp;schema, std::string &amp;error)']]],
  ['compoundlayout_50',['CompoundLayout',['../classavro_1_1CompoundLayout.html',1,'avro']]],
  ['copy_51',['copy',['../namespaceavro.html#adeab3d9f5f2a4a4f96d3ffb8ba27e523',1,'avro']]],
  ['currentbranch_52',['currentBranch',['../classavro_1_1GenericUnion.html#a97b5f0a1aaffc36fa8797a17cf8abe0f',1,'avro::GenericUnion']]]
];

==> avro-doc-1.11.5.tar.gz: avro-doc-1.11.5/api/cpp/html/search/all_2.js <==
var searchData=
[
  ['close_32',['close',['../classavro_1_1DataFileWriterBase.html#abc2bf032070c962eee3628abbb062edf',1,'avro::DataFileWriterBase::close()'],['../classavro_1_1DataFileWriter.html#a3ed294a4c9e3641b4cbd383ede5aedc1',1,'avro::DataFileWriter::close()'],['../classavro_1_1DataFileReaderBase.html#ad10eaf9462e2464c37d3a1f4eebc702b',1,'avro::DataFileReaderBase::close()'],['../classavro_1_1DataFileReader.html#af92068c4498f900939e3208a2c370b2e',1,'avro::DataFileReader::close()']]],
  ['codec_33',['Codec',['../namespaceavro.html#a348c1fae0c6b9d7524b00be30a2746b2',1,'avro']]],
  ['codec_5ftraits_34',['codec_traits',['../structavro_1_1codec__traits.html',1,'avro']]],
  ['codec_5ftraits_3c_20avro_3a_3anull_20_3e_35',['codec_traits&lt; avro::null &gt;',['../structavro_1_1codec__traits_3_01avro_1_1null_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20bool_20_3e_36',['codec_traits&lt; bool &gt;',['../structavro_1_1codec__traits_3_01bool_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20double_20_3e_37',['codec_traits&lt; double &gt;',['../structavro_1_1codec__traits_3_01double_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20float_20_3e_38',['codec_traits&lt; float &gt;',['../structavro_1_1codec__traits_3_01float_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20genericdatum_20_3e_39',['codec_traits&lt; GenericDatum &gt;',['../structavro_1_1codec__traits_3_01GenericDatum_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20int32_5ft_20_3e_40',['codec_traits&lt; int32_t &gt;',['../structavro_1_1codec__traits_3_01int32__t_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20int64_5ft_20_3e_41',['codec_traits&lt; int64_t &gt;',['../structavro_1_1codec__traits_3_01int64__t_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3aarray_3c_20uint8_5ft_2c_20n_20_3e_20_3e_42',['codec_traits&lt; std::array&lt; uint8_t, N &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1array_3_01uint8__t_00_01N_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3aconditional_3c_20avro_3a_3ais_5fnot_5fdefined_3c_20bool_5fcodec_5ftraits_20_3e_3a_3avalue_2c_20std_3a_3avector_3c_20bool_20_3e_3a_3aconst_5freference_2c_20void_20_3e_3a_3atype_20_3e_43',['codec_traits&lt; std::conditional&lt; avro::is_not_defined&lt; bool_codec_traits &gt;::value, std::vector&lt; bool &gt;::const_reference, void &gt;::type &gt;',['../structavro_1_1codec__traits_3_01std_1_1conditional_3_01avro_1_1is__not__defined_3_01bool__codec_ff37ba08cb2504ad1efb9929401153b7.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3amap_3c_20std_3a_3astring_2c_20t_20_3e_20_3e_44',['codec_traits&lt; std::map&lt; std::string, T &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1map_3_01std_1_1string_00_01T_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3apair_3c_20validschema_2c_20genericdatum_20_3e_20_3e_45',['codec_traits&lt; std::pair&lt; ValidSchema, GenericDatum &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1pair_3_01ValidSchema_00_01GenericDatum_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3astring_20_3e_46',['codec_traits&lt; std::string &gt;',['../structavro_1_1codec__traits_3_01std_1_1string_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3avector_3c_20t_20_3e_20_3e_47',['codec_traits&lt; std::vector&lt; T &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1vector_3_01T_01_4_01_4.html',1,'avro']]],
  ['codec_5ftraits_3c_20std_3a_3avector_3c_20uint8_5ft_20_3e_20_3e_48',['codec_traits&lt; std::vector&lt; uint8_t &gt; &gt;',['../structavro_1_1codec__traits_3_01std_1_1vector_3_01uint8__t_01_4_01_4.html',1,'avro']]],
  ['compilejsonschema_49',['compileJsonSchema',['../namespaceavro.html#a31c14823127aff747cc83e6714de9e31',1,'avro::compileJsonSchema(std::istream &amp;is, ValidSchema &amp;schema)'],['../namespaceavro.html#a23cb7c42622aad8310cffa013c022d14',1,'avro::compileJsonSchema(std::istream &amp;is, ValidSchema &amp;schema, std::string &amp;error)']]],
  ['compoundlayout_50',['CompoundLayout',['../classavro_1_1CompoundLayout.html',1,'avro']]],
  ['copy_51',['copy',['../namespaceavro.html#adeab3d9f5f2a4a4f96d3ffb8ba27e523',1,'avro']]],
  ['currentbranch_52',['currentBranch',['../classavro_1_1GenericUnion.html#a97b5f0a1aaffc36fa8797a17cf8abe0f',1,'avro::GenericUnion']]],
  ['customattributes_53',['CustomAttributes',['../classavro_1_1CustomAttributes.html',1,'avro']]]
];
